/* float.h   header file for the floating-point constant module of
 * 	     the Netwide Assembler
 *
 * The Netwide Assembler is copyright (C) 1996 Simon Tatham and
 * Julian Hall. All rights reserved. The software is
 * redistributable under the licence given in the file "Licence"
 * distributed in the NASM archive.
 */

#ifndef NASM_FLOAT_H
#define NASM_FLOAT_H

/* #define FORKED_NASM */                                  /* define to target forked NASM */

#ifndef FORKED_NASM

typedef               char Bool_t;                         /* must be at least 1 bit */

typedef               char Sint8_t;                        /* must be 1 byte */
typedef unsigned      char Uint8_t;                        /* must be 1 byte */

typedef          short int Sint16_t;                       /* must be 2 bytes */
typedef unsigned short int Uint16_t;                       /* must be 2 bytes */

typedef                int Sint32_t;                       /* must be 4 bytes */
typedef unsigned       int Uint32_t;                       /* must be 4 bytes */

#define ERR_TYPE_PANIC ERR_PANIC
#define ERR_TYPE_ERROR ERR_NONFATAL
#define ERR_TYPE_WARN  ERR_WARNING

#define ERR_WARN_FPA   0
#define ERR_WARN_FPO   0
#define ERR_WARN_FPD   0
#define ERR_WARN_FPU   0

Bool_t float_const ( const Sint8_t *string,
                     Sint32_t sign,
                     Uint8_t *result,
                     Sint32_t bytes,
                     efunc error );

#else

Bool_t float_const ( const Sint8_t *string,
                     Sint32_t sign,
                     Uint8_t *result,
                     Sint32_t bytes );

#endif

Bool_t float_get_daz ( void );

void float_set_daz ( Bool_t state );

#define FLOAT_DAZ_OFF FALSE
#define FLOAT_DAZ_ON  TRUE

#define FLOAT_DAZ_DEFAULT FLOAT_DAZ_OFF                    /* for compatibility with earlier versions */

Uint8_t float_get_rc ( void );

void float_set_rc ( Uint8_t type );

#define FLOAT_RC_NEAR 0
#define FLOAT_RC_DOWN 1
#define FLOAT_RC_UP   2
#define FLOAT_RC_ZERO 3

#define FLOAT_RC_DEFAULT FLOAT_RC_NEAR                     /* for compatibility with earlier versions */

#endif                                                     /* NASM_FLOAT_H */

/* EOF */
